@@ -1,41 +1,4 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is the Update Service.
- *
- * The Initial Developer of the Original Code is Ben Goodger.
- * Portions created by the Initial Developer are Copyright (C) 2004
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *  Ben Goodger <ben@mozilla.org> (Original Author)
- *  Darin Fisher <darin@meer.net>
- *  Ben Turner <bent.mozilla@gmail.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+//@line 41 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
 const PREF_APP_UPDATE_ENABLED             = "app.update.enabled";
 const PREF_APP_UPDATE_AUTO                = "app.update.auto";
@@ -116,6 +79,7 @@ const Node = Components.interfaces.nsIDOMNode;
 var gApp        = null;
 var gPref       = null;
 var gOS         = null;
+var gABI        = null;
 var gConsole    = null;
 var gLogEnabled = { };
 
@@ -854,6 +818,16 @@ function UpdateService() {
   gConsole = Components.classes["@mozilla.org/consoleservice;1"]
                        .getService(Components.interfaces.nsIConsoleService);  
 
+  // Not all builds have a known ABI
+  try {
+    gABI = gApp.XPCOMABI;
+  }
+  catch (e) {
+    LOG("UpdateService", "XPCOM ABI unknown: updates are not possible.");
+  }
+
+//@line 877 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+
   // Start the update timer only after a profile has been selected so that the
   // appropriate values for the update check are read from the user's profile.  
   gOS.addObserver(this, "profile-after-change", false);
@@ -1302,6 +1276,11 @@ UpdateService.prototype = {
     var enabled = getPref("getBoolPref", PREF_APP_UPDATE_ENABLED, true);
     if (!enabled && gPref.prefIsLocked(PREF_APP_UPDATE_ENABLED))
       return false;
+
+    // If we don't know the binary platform we're updating, we can't update.
+    if (!gABI)
+      return false;
+
     return true;
   },
   
@@ -1686,7 +1665,7 @@ Checker.prototype = {
     url = url.replace(/%PRODUCT%/g, gApp.name);
     url = url.replace(/%VERSION%/g, gApp.version);
     url = url.replace(/%BUILD_ID%/g, gApp.appBuildID);
-    url = url.replace(/%BUILD_TARGET%/g, gApp.OS + "_" + gApp.XPCOMABI);
+    url = url.replace(/%BUILD_TARGET%/g, gApp.OS + "_" + gABI);
     url = url.replace(/%LOCALE%/g, getLocale());
     url = url.replace(/%CHANNEL%/g, getUpdateChannel());
     url = url.replace(/\+/g, "%2B");
@@ -2472,7 +2451,7 @@ TimerManager.prototype = {
   }
 };
 
-//@line 2476 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2502 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 /**
  * UpdatePrompt
  * An object which can prompt the user with information about updates, request
@@ -2614,7 +2593,7 @@ UpdatePrompt.prototype = {
     return this;
   }
 };
-//@line 2618 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2644 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
 var gModule = {
   registerSelf: function(componentManager, fileSpec, location, type) {
@@ -2666,13 +2645,13 @@ var gModule = {
                className  : "Update Checker",
                factory    : #1#(Checker)
              },
-//@line 2670 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2696 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     prompt:  { CID        : Components.ID("{27ABA825-35B5-4018-9FDD-F99250A0E722}"),
                contractID : "@mozilla.org/updates/update-prompt;1",
                className  : "Update Prompt",
                factory    : #1#(UpdatePrompt)
              },
-//@line 2676 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2702 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     timers:  { CID        : Components.ID("{B322A5C0-A419-484E-96BA-D7182163899F}"),
                contractID : "@mozilla.org/updates/timer-manager;1",
                className  : "Timer Manager",
@@ -2703,14 +2682,14 @@ function NSGetModule(compMgr, fileSpec) {
  *          the specified update, false otherwise.
  */
 function isCompatible(update) {
-//@line 2707 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2733 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   var em = 
       Components.classes["@mozilla.org/extensions/manager;1"].
       getService(Components.interfaces.nsIExtensionManager);
   var items = em.getIncompatibleItemList("", update.extensionVersion,
     nsIUpdateItem.TYPE_ADDON, false, { });
   return items.length == 0;
-//@line 2716 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2742 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 }
 
 /**
@@ -2729,7 +2708,7 @@ function showPromptIfNoIncompatibilities(update) {
     prompter.showUpdateAvailable(update);
   }
 
-//@line 2735 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2761 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   /**
    * Determines if an addon is compatible with a particular update.
    * @param   addon
@@ -2829,6 +2808,6 @@ function showPromptIfNoIncompatibilities(update) {
     em.update([], 0, mode != 0, listener);
   }
   else
-//@line 2835 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2861 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     showPrompt(update);
 }
