@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -74,14 +74,11 @@ function openNewWindowWith(href, sourceURL, postData)
  */
 function urlSecurityCheck(url, sourceURL)
 {
-  var sourceURI = makeURI(sourceURL);
-  var destURI = makeURI(url);
-
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
   try {
-    secMan.checkLoadURI(sourceURI, destURI, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(sourceURL, url, nsIScriptSecurityManager.STANDARD);
   } catch (e) {
     throw "Load of " + url + " from " + sourceURL + " denied.";
   }
@@ -460,9 +457,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 507 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 504 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 510 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 507 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -850,7 +847,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 901 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 898 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/content/contentAreaUtils.js"
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
