@@ -1,6 +1,6 @@
-//@line 40 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 40 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 
-//@line 42 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 42 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 var helpBrowser;
 var helpSearchPanel;
 var emptySearch;
@@ -12,16 +12,16 @@ var helpGlossaryPanel;
 var strBundle;
 var gTocDSList = "";
 
-//@line 54 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 54 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 const NC = "http://home.netscape.com/NC-rdf#";
 const MAX_LEVEL = 40; // maximum depth of recursion in search datasources.
 const MAX_HISTORY_MENU_ITEMS = 6;
 
-//@line 68 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 68 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 const platform = "unix";
-//@line 72 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 72 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 
-//@line 74 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 74 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 const RDF = Components.classes["@mozilla.org/rdf/rdf-service;1"]
     .getService(Components.interfaces.nsIRDFService);
 const RDF_ROOT = RDF.GetResource("urn:root");
@@ -48,9 +48,13 @@ var RE;
 
 var helpFileURI;
 var helpFileDS;
-//@line 102 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 102 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 var helpBaseURI;
 
+var gIgnoreFocus = false;
+var gClickSelectsAll;
+var gIgnoreClick = false;
+
 /* defaultTopic is either set
    1. in the openHelp() call, passed as an argument to the Help window and
       evaluated in init(), or
@@ -62,7 +66,7 @@ var defaultTopic;
 
 const NSRESULT_RDF_SYNTAX_ERROR = 0x804e03f7;
 
-//@line 119 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 123 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function displayTopic(topic) {
     // Get the page to open.
     var uri = getLink(topic);
@@ -75,7 +79,7 @@ function displayTopic(topic) {
       loadURI(uri);
 }
 
-//@line 132 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 136 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function init() {
   // Cache panel references.
   helpSearchPanel = document.getElementById("help-search-panel");
@@ -122,9 +126,8 @@ function init() {
 
   webProgress.addProgressListener(window.XULBrowserWindow, Components.interfaces.nsIWebProgress.NOTIFY_ALL);
 
-  var searchBox = document.getElementById("findText");
-  searchBox.clickSelectsAll = getBoolPref("browser.urlbar.clickSelectsAll", true);
-
+  gClickSelectsAll = getBoolPref("browser.urlbar.clickSelectsAll", true);
+  
   setTimeout(focusSearch, 0);
 }
 
@@ -156,7 +159,7 @@ function hideSearchSidebar(aEvent) {
   tableOfContents.removeAttribute("hidden");
 }
 
-//@line 216 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 219 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function loadHelpRDF() {
   if (!helpFileDS) {
     try {
@@ -231,12 +234,12 @@ function loadHelpRDF() {
   }
 }
 
-//@line 292 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 295 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function filterDatasourceByPlatform(aDatasource) {
   filterNodeByPlatform(aDatasource, RDF_ROOT, 0);
 }
 
-//@line 298 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 301 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function filterNodeByPlatform(aDatasource, aCurrentResource, aCurrentLevel) {
   if (aCurrentLevel > MAX_LEVEL) {
      log("Datasources over " + MAX_LEVEL + " levels deep are unsupported.");
@@ -253,7 +256,7 @@ function filterNodeByPlatform(aDatasource, aCurrentResource, aCurrentLevel) {
   }
 }
 
-//@line 317 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 320 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function filterSeqByPlatform(aDatasource, aNode, aCurrentLevel) {
   // get nc:subheading children into an enumerator
   var RDFC = Components.classes["@mozilla.org/rdf/container;1"]
@@ -286,7 +289,7 @@ function filterSeqByPlatform(aDatasource, aNode, aCurrentLevel) {
   }
 }
 
-//@line 351 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 354 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function normalizeLinks(helpBaseURI, links) {
   if (!helpBaseURI) {
     return links;
@@ -328,7 +331,7 @@ function getLink(ID) {
     return null;
 }
 
-//@line 394 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 397 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function getHelpFileURI() {
     return helpFileURI;
 }
@@ -363,6 +366,33 @@ function goBack() {
   }
 }
 
+/* copied from browser.js */
+function BrowserReloadWithFlags(reloadFlags) {
+    /* First, we'll try to use the session history object to reload so 
+     * that framesets are handled properly. If we're in a special 
+     * window (such as view-source) that has no session history, fall 
+     * back on using the web navigation's reload method.
+     */
+
+    var webNav = getWebNavigation();
+    try {
+      var sh = webNav.sessionHistory;
+      if (sh)
+        webNav = sh.QueryInterface(Components.interfaces.nsIWebNavigation);
+    } catch (e) {
+    }
+
+    try {
+      webNav.reload(reloadFlags);
+    } catch (e) {
+    }
+}
+
+function reload() {
+  const reloadFlags = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE;
+  return BrowserReloadWithFlags(reloadFlags);
+}
+
 function goForward() {
     try
     {
@@ -540,12 +570,39 @@ function onselect_loadURI(tree) {
     }// when switching between tabs a spurious row number is returned.
 }
 
+// copied from browser.js to handle the searchbar
+function SearchbarFocusHandler(aEvent, aElt)
+{
+  if (gIgnoreFocus)
+    gIgnoreFocus = false;
+  else if (gClickSelectsAll)
+    aElt.select();
+}
+
+function SearchbarMouseDownHandler(aEvent, aElt)
+{
+  if (aElt.hasAttribute("focused")) {
+    gIgnoreClick = true;
+  } else {
+    gIgnoreFocus = true;
+    gIgnoreClick = false;
+    aElt.setSelectionRange(0, 0);
+  }
+}
+
+function SearchbarClickHandler(aEvent, aElt)
+{
+  if (!gIgnoreClick && gClickSelectsAll && aElt.selectionStart == aElt.selectionEnd)
+    aElt.select();
+}
+
+
 function focusSearch() {
   var searchBox = document.getElementById("findText");
   searchBox.focus();
 }
 
-//@line 612 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 669 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function doFind() {
     if (document.getElementById("help-search-sidebar").hidden)
       showSearchSidebar();
@@ -695,7 +752,7 @@ function getLiteralValue(literal, defaultValue) {
     return null;
 }
 
-//@line 762 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 819 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function log(aText) {
     CONSOLE_SERVICE.logStringMessage(aText);
 }
@@ -712,7 +769,7 @@ function getBoolPref (aPrefname, aDefault)
   }
 }
 
-//@line 779 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/components/help/content/help.js"
+//@line 836 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.EL_Depend/mozilla/toolkit/components/help/content/help.js"
 function getXulWin()
 {
   window.QueryInterface(Components.interfaces.nsIInterfaceRequestor);
