@@ -1,4 +1,4 @@
-//@line 37 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/update.js"
+//@line 37 "/builds/tinderbox/XR-Mozilla1.8.0-Release/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/update.js"
 
 //
 // This UI can be opened from the following places, and in the following modes:
@@ -158,9 +158,9 @@ var gVersionInfoPage = {
     else {
       // VersionInfo compatibility updates resolved all compatibility problems,
       // close this window and continue starting the application...
-      // We need to click the cancel button to wake up the ui due to the way the
-      // EM is using xmlHttpRequest when checking for updates.
-      document.documentElement.getButton("cancel").click();
+      //XXX Bug 314754 - We need to use setTimeout to close the window due to
+      // the EM using xmlHttpRequest when checking for updates.
+      setTimeout(close, 0);
     }
   },
   
