@@ -9,11 +9,11 @@ package org.mozilla.xpcom;
 
 public interface nsIDOMHTMLHeadElement extends nsIDOMHTMLElement
 {
-  String NS_IDOMHTMLHEADELEMENT_IID =
+  public static final String NS_IDOMHTMLHEADELEMENT_IID =
     "{a6cf9087-15b3-11d2-932e-00805f8add32}";
 
-  String getProfile();
+  public String getProfile();
 
-  void setProfile(String arg1);
+  public void setProfile(String arg1);
 
 }
