@@ -9,17 +9,17 @@ package org.mozilla.xpcom;
 
 public interface nsIDOMSVGZoomEvent extends nsIDOMUIEvent
 {
-  String NS_IDOMSVGZOOMEVENT_IID =
+  public static final String NS_IDOMSVGZOOMEVENT_IID =
     "{339a8c7a-552e-4cbc-8d96-8370a3939358}";
 
-  nsIDOMSVGRect getZoomRectScreen();
+  public nsIDOMSVGRect getZoomRectScreen();
 
-  float getPreviousScale();
+  public float getPreviousScale();
 
-  nsIDOMSVGPoint getPreviousTranslate();
+  public nsIDOMSVGPoint getPreviousTranslate();
 
-  float getNewScale();
+  public float getNewScale();
 
-  nsIDOMSVGPoint getNewTranslate();
+  public nsIDOMSVGPoint getNewTranslate();
 
 }
