@@ -9,7 +9,7 @@ package org.mozilla.xpcom;
 
 public interface nsIDataChannel extends nsIChannel
 {
-  String NS_IDATACHANNEL_IID =
+  public static final String NS_IDATACHANNEL_IID =
     "{7e835f60-5fea-11d3-a177-0050041caf44}";
 
 }
